@@ -1,7 +1,8 @@
 re_id_list = [
     "[A-Za-z0-9]+[\d@]+[\w@]*",
     "[\d@]+[A-Za-z0-9]+[\w@]*",
-    "[\d]+[\/-]*[A-Za-z]+[\/-]*[\w]*",
+    "[\d]+[\/\-]*[\w]+[\/\-]*[\w]*", #1673/QĐ-UBND
+
     # "([A-Za-z0-9]{2,5}[-\/]){1,}[A-Za-z0-9]{2,}",
     "\d{7,}",
 ]
\ No newline at end of file
